@@ -8,7 +8,7 @@ use parent 'Perl::Critic::Policy';
 
 use List::Util 'any';
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use constant DESC => 'Using function prototypes';
 use constant EXPL => 'Function prototypes (sub foo ($@) { ... }) will usually not do what you want. Omit the prototype, or use signatures instead.';
@@ -28,7 +28,8 @@ sub violates {
 	my $prototypes = $elem->find('PPI::Token::Prototype') || [];
 	my @violations;
 	foreach my $prototype (@$prototypes) {
-		next if $prototype->prototype eq ''; # Leave empty prototypes alone
+		# Empty prototypes and prototypes containing & can be useful
+		next if $prototype->prototype eq '' or $prototype->prototype =~ /&/;
 		push @violations, $self->violation(DESC, EXPL, $prototype);
 	}
 	
@@ -53,6 +54,9 @@ modern method of declaring arguments.
   sub foo { ... }      # ok
   use feature 'signatures'; sub foo ($bar, $baz) { ... } # ok
 
+Note that this policy does not warn about empty prototypes or prototypes
+containing C<&>, as those are often useful for structural behavior.
+
 =head1 AFFILIATION
 
 This policy is part of L<Perl::Critic::Freenode>.
